==> changelog-0.1.0.tgz: package/changelog.md <==
Upcoming / 2011-08-23
=====================

  * update version
  * show the author's name if the repo url is not in the module's package.json.
  * fix exception that happens when a module isn't found
  * clean up readme
  * fix screenshot urls
  * updated examples and added screenshots

0.0.9 / 2011-08-23
==================

  * update version
  * update examples
  * show full url to to github issue on command line output

0.0.8 / 2011-08-16
==================

  * updated version
  * updated examples
  * don't include ansi color codes when outputting to a file or pipe

0.0.7 / 2011-08-010
===================

  * upped version
  * added changelog for changelog
  * run changelog in the root of a node project with a package.json and it will use it to
    create the changelog.

0.0.6 / 2011-08-06
==================

  * bumped version to 0.0.6
  * added lots of examples
  * added --color output (new default)
  * get debug output via --debug

0.0.5 / 2011-08-05
==================

  * up version
  * handle better npm's api not being available
    wrap text using the screen width via tty
  * remove node_modules from git project

0.0.4 / 2011-08-04
==================

  * update version to 0.0.4
  * using issac's semver to compare module version numbers
  * update readme

0.0.3 / 2011-08-03
==================

  * update readme
  * support upcoming features that are in github but not yet in npm.
  * up to 0.0.3
  * --json support
  * update description

0.0.2 / 2011-08-03
==================

  * version 0.0.2
  * use standard out and standard error for output.
    don't bubble exceptions or repeat error messages.

0.0.1 / 2011-08-01
==================

  * First commit

==> changelog-0.1.2.tgz: package/changelog.md <==
Upcoming / 2011-08-24
=====================

  * fixed regex for replacing github ticket numbers with url to the ticket so it wouldn't
    blindly match #.

0.1.0 / 2011-08-23
==================

  * update changelog
  * update version
  * show the author's name if the repo url is not in the module's package.json.
  * fix exception that happens when a module isn't found
  * clean up readme
  * fix screenshot urls
  * updated examples and added screenshots

0.0.9 / 2011-08-23
==================

  * update version
  * update examples
  * show full url to to github issue on command line output

0.0.8 / 2011-08-16
==================

  * updated version
  * updated examples
  * don't include ansi color codes when outputting to a file or pipe

0.0.7 / 2011-08-010
===================

  * upped version
  * added changelog for changelog
  * run changelog in the root of a node project with a package.json and it will use it to create
    the changelog.

0.0.6 / 2011-08-06
==================

  * bumped version to 0.0.6
  * added lots of examples
  * added --color output (new default)
  * get debug output via --debug

0.0.5 / 2011-08-05
==================

  * up version
  * handle better npm's api not being available
    wrap text using the screen width via tty
  * remove node_modules from git project

0.0.4 / 2011-08-04
==================

  * update version to 0.0.4
  * using issac's semver to compare module version numbers
  * update readme

0.0.3 / 2011-08-03
==================

  * update readme
  * support upcoming features that are in github but not yet in npm.
  * up to 0.0.3
  * --json support
  * update description

0.0.2 / 2011-08-03
==================

  * version 0.0.2
  * use standard out and standard error for output.
    don't bubble exceptions or repeat error messages.

0.0.1 / 2011-08-01
==================

  * First commit
